Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1127)

Unified Diff: content/browser/renderer_host/pepper/pepper_message_filter.cc

Issue 11360052: Add a 'NACL' plugin type to PepperMessageFilter so we can block private APIs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/pepper/pepper_message_filter.cc
===================================================================
--- content/browser/renderer_host/pepper/pepper_message_filter.cc (revision 165369)
+++ content/browser/renderer_host/pepper/pepper_message_filter.cc (working copy)
@@ -110,7 +110,7 @@
host_resolver_(host_resolver),
next_socket_id_(1),
incognito_(false) {
- DCHECK(type == PLUGIN);
+ DCHECK(type == PLUGIN || type == NACL);
DCHECK(host_resolver);
}
@@ -812,7 +812,7 @@
bool PepperMessageFilter::CanUseSocketAPIs(int32 render_id) {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::UI));
if (process_type_ == PLUGIN) {
// Always allow socket APIs for out-process plugins.
return true;
}
@@ -812,7 +812,7 @@
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::UI));
if (process_type_ == PLUGIN) {
- // Always allow socket APIs for out-process plugins.
+ // Always allow socket APIs for out-process plugins (except NACL).
return true;
}

Powered by Google App Engine
This is Rietveld 408576698